@echo off

SETLOCAL

set VERSION=DIGSI 4.84 Hotfix 3

title Installing %VERSION% ...

:: cmd.exe does not support UNC paths, see Microsoft knowledge base Q156276.
:: If the batch file is started from a network path
:: the current directory defaults to the Windows directory. 
:: If this is the case, we abort this batch file here.
:: %cd% returns the current directory
if #"%cd%"#==#"%windir%"# goto ERROR_UNC

:: When a batch file is started via "Run as administrator" under Windows Vista
:: the current directory is C:\Windows\system32 
:: (not the directory where the batch file is located as it is the case under Win XP)
:: to change directory: %0 is the path of this batch as given
:: %~f0 is always the full path and filename of this batch
:: %~d0 is the drive (d), e.g. d:, %~dp0 is the drive (d) and path (p) part 

:: change drive
%~d0
:: change directory
CD %~dp0

:: under Vista: check necessary user rights to write into "Common Files" and into registry
:: When a batch file is started via "Run as administrator" under Windows Vista

VER | find /i "6.0." > nul
IF %ERRORLEVEL% EQU 0 GOTO VISTA
GOTO CONTINUE1


:VISTA

:: running on Windows Vista

:: a normal user, even when he is an administrator, runs this batch with 
:: security level Medium (Mittel), SID=S-1-16-8192
:: to write into "Common Files" and into the registry we need at least
:: security level High (Hoch), SID=S-1-16-12288
whoami /user /groups | find "S-1-16-12288" > nul
if errorlevel 1 GOTO ERROR_INSUFFICIENT_USER_RIGHTS


:CONTINUE1

echo Installing %VERSION% ...
echo.
echo Please read the ReadMe file carefully that came with %VERSION%.
echo ------
pause

:: no files for SysCon in this version
:: => skip SysCon check + install steps
goto DIGSIINSTALL

:: SysCon version should be stored in 
:: HKEY_LOCAL_MACHINE\SOFTWARE\Siemens\SYSCON\USERINFO\VERSION
:: check if SysCon is installed
REG QUERY "HKLM\SOFTWARE\Siemens\SYSCON" >nul
if errorlevel 1 (
	echo Error reading HKLM\SOFTWARE\Siemens\SYSCON\USERINFO
	echo No SysCon installed
	echo Continue with DIGSI 4 installation... 
	pause
	goto DIGSIINSTALL
)

:: detect SysCon version
:: delims is a TAB followed by a space
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\SYSCON\USERINFO" /v VERSION') DO SET SCVER=%%B
SET SHORTSCVER=%SCVER:~0,5%

:: for debugging
::echo SCVER: '%SCVER%'
::echo SHORTSCVER: '%SHORTSCVER%'
::pause

if %SHORTSCVER% == 04.84 (
	goto SYSCONINSTALL
) else (
	echo %VERSION% can only update SysCon V4.84. 
	echo It shall not be applied to the installed SysCon V%SCVER:~0,5%.
	echo Continue with DIGSI 4 installation... 
	pause
	goto DIGSIINSTALL
)


:SYSCONINSTALL

:: The full path to the SysKon installation folder should be stored in 
:: HKEY_LOCAL_MACHINE\SOFTWARE\Siemens\SYSCON\PROGRAMS\SysCon

:: detect SysCon installation directory (the path of IEC61850Conf.exe)
:: default is C:\Siemens\Digsi4\SysKon\Configurator
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKEY_LOCAL_MACHINE\SOFTWARE\Siemens\SYSCON\PROGRAMS" /v SysCon') DO SET SysConPath=%%B
if #"%SysConPath%"#==#""# goto DIGSIINSTALL

:: for debugging
::echo SysConPath: '%SysConPath%'
::pause

echo Copying SysCon files...
xcopy /I /E /Y /F /R SYSCON\*.*	"%SysConPath%"

:: write date, time and what is installed into a textfile
echo ---	>>"%SysConPath%"\Updates.txt
date /t	>>"%SysConPath%"\Updates.txt
time /t	>>"%SysConPath%"\Updates.txt
echo %VERSION%	>>"%SysConPath%"\Updates.txt


:DIGSIINSTALL

:: check if DIGSI4 is installed
REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO" >nul
if errorlevel 1 (
	echo Error reading HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO
	echo Please check your DIGSI 4 installation. 
	pause
	goto ERROR_REGISTRY_ERROR
)

:: detect DIGSI 4 version
:: delims is a TAB followed by a space
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\USERINFO" /v VERSION') DO SET DIGVER=%%B
SET SHORTVER=%DIGVER:~0,4%

if %SHORTVER% == 4.84 (
	goto CONTINUE2
) else (
	echo %VERSION% can only be used to update DIGSI V4.84. 
	echo It shall not be applied to the installed DIGSI V%DIGVER:~0,4%.
	pause
	goto END1
)


:CONTINUE2

:: check if DotNetFramework is installed
REG QUERY "HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\.NETFramework" >Nul
if errorlevel 1 (
	echo Error reading HKLM\SOFTWARE\Microsoft\.NETFramework
	goto ERROR_DOTNETFRAMEWORK_ERROR
)

:: detect Step7 Manager installation directory (the path of s7bin\S7tgtopx.exe)
:: default is
:: C:\Siemens\Step7\s7bin if Step7 full version is used
:: C:\Siemens\Digsi4\Manager\s7bin if DIGSI 4 OEM version of Step7 is used
:: delims is a TAB followed by a space
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\AUTSW\STEP7" /v Path') DO SET ManagerPath=%%B\
if #"%ManagerPath%"#==#""# goto ERROR_NO_MANAGERPATH
if #"%ManagerPath%"#==#"\"# goto ERROR_NO_MANAGERPATH

:: detect DIGSI4 installation directory (the path of Digsi4.exe)
:: default is C:\Siemens\Digsi4\
FOR /F "tokens=2* delims=	 " %%A IN ('REG QUERY "HKLM\SOFTWARE\Siemens\DIGSI4\PROGRAMME" /v Digsi') DO SET DigsiPath=%%B
if #"%DigsiPath%"#==#""# goto ERROR_NO_DIGSIPATH

:: copy all supplied files (except SysCon)
echo Copying DIGSI DeviceEditor files...
xcopy /I /E /Y /F /R DIGSI4\*.*	"%DigsiPath%"
echo Copying DIGSI Manager files...
xcopy /I /E /Y /F /R MANAGER\*.*	"%ManagerPath%"
:: xcopy /I /E /Y /F /R COMMONFILES\*.*	"%CommonProgramFiles%"

:: write date, time and what is installed into a textfile
echo ---	>>"%DigsiPath%"\Updates.txt
date /t	>>"%DigsiPath%"\Updates.txt
time /t	>>"%DigsiPath%"\Updates.txt
echo %VERSION%	>>"%DigsiPath%"\Updates.txt

:: display the product information file 
:: (using the default PDF reader application)
echo ------
set /P choice=Display Product Info with the default PDF reader program? (y/n)
if /i "%choice%"=="y" goto:SHOW_PRODUCTINFO
goto END1


:SHOW_PRODUCTINFO

GNL_DIGSI-V4.84_HF3_Readme.pdf

goto END1


:ERROR_UNC

echo ------
echo Solution: copy %VERSION% into a directory on your local PC or
echo assign a drive letter to the network drive via "net use" and start from there
goto END1


:ERROR_NO_MANAGERPATH
echo ------
echo Could not read path of Step 7 Manager from the registry
echo Please check your installation of Step 7 and/or DIGSI 4
goto END1


:ERROR_NO_DIGSIPATH
echo ------
echo Could not read DIGSI 4 path from the registry
echo Please check your DIGSI 4 installation
goto END1


:ERROR_REGISTRY_ERROR
echo Registry access failed.
goto END1


:ERROR_DOTNETFRAMEWORK_ERROR
echo %VERSION% needs at least Microsoft .Net Framework 2.0
echo Please check your DotNetFramework installation. 
goto END1


:ERROR_INSUFFICIENT_USER_RIGHTS
echo Insufficient user rights for Windows Vista.
echo Please run this batch file via 
echo right click - "Run as administrator"
echo even if you already are an administrator.
goto END1


:END1

echo ------
echo End of %VERSION% installation
echo ------
pause

